@@ -141,6 +141,9 @@ static XtResource appDataResourceList[] = {
   {"fullScreen", "FullScreen", XtRBool, sizeof(Bool),
    XtOffsetOf(AppData, fullScreen), XtRImmediate, (XtPointer) False},
 
+  {"raiseOnBeep", "RaiseOnBeep", XtRBool, sizeof(Bool),
+   XtOffsetOf(AppData, raiseOnBeep), XtRImmediate, (XtPointer) True},
+
   {"passwordFile", "PasswordFile", XtRString, sizeof(String),
    XtOffsetOf(AppData, passwordFile), XtRImmediate, (XtPointer) 0},
 
@@ -216,6 +219,7 @@ XrmOptionDescRec cmdLineOptions[] = {
   {"-noshared",      "*shareDesktop",       XrmoptionNoArg,  "False"},
   {"-viewonly",      "*viewOnly",           XrmoptionNoArg,  "True"},
   {"-fullscreen",    "*fullScreen",         XrmoptionNoArg,  "True"},
+  {"-noraiseonbeep", "*raiseOnBeep",        XrmoptionNoArg,  "False"},
   {"-passwd",        "*passwordFile",       XrmoptionSepArg, 0},
   {"-encodings",     "*encodings",          XrmoptionSepArg, 0},
   {"-bgr233",        "*useBGR233",          XrmoptionNoArg,  "True"},
@@ -273,18 +277,18 @@ void
 usage(void)
 {
   fprintf(stderr,
-	  "TightVNC viewer version 1.2.1 (based on VNC 3.3.3r2)\n"
+	  "TightVNC viewer version 1.2.2 (based on VNC 3.3.3r2)\n"
 	  "\n"
-	  "Usage: %s [<OPTIONS>] [<HOST>]:<DISPLAY#>\n"
+	  "Usage: %s [<OPTIONS>] [<HOST>][:<DISPLAY#>]\n"
 	  "       %s [<OPTIONS>] -listen [<DISPLAY#>]\n"
-	  "       %s [<OPTIONS>] -tunnel <HOST>:<DISPLAY#>\n"
-	  "       %s [<OPTIONS>] -via <GATEWAY> [<HOST>]:<DISPLAY#>\n"
 	  "\n"
 	  "<OPTIONS> are standard Xt options, or:\n"
+	  "        -via <GATEWAY>\n"
 	  "        -shared (set by default)\n"
 	  "        -noshared\n"
 	  "        -viewonly\n"
 	  "        -fullscreen\n"
+	  "        -noraiseonbeep\n"
 	  "        -passwd <PASSWD-FILENAME>\n"
 	  "        -encodings <ENCODING-LIST> (e.g. \"tight copyrect\")\n"
 	  "        -bgr233\n"
@@ -294,7 +298,9 @@ usage(void)
 	  "        -compresslevel <COMPRESS-VALUE> (0..9: 0-fast, 9-best)\n"
 	  "        -quality <JPEG-QUALITY-VALUE> (0..9: 0-low, 9-high)\n"
 	  "        -nocursorshape\n"
-	  "\n", programName, programName, programName, programName);
+	  "\n"
+	  "Option names may be abbreviated, e.g. -bgr instead of -bgr233.\n"
+	  "\n", programName, programName);
   exit(1);
 }
 
